# Mini Hiera

Puppet's Hiera library felt usable as a free-standing hierarchial key lookup library, but they pulled the source back into the Puppet codebase, thereby limiting any potential use outside Puppet itself.

This is a free-standing gem that clean-room implements the behaviour of Hiera such that it can be used in any project.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'mini_hiera'
```

## Usage

The simplest way to use this gem is to provide a directory of `YAML` files and configure a hierarchy in code:

```yaml
config/device/device1.yaml:
test_key: "loaded from device/device1.yaml"

config/device/device2.yaml:
test_key: "loaded from device/device2.yaml"

config/site/site1.yaml
test_key: "loaded from site/site1.yaml"

config/type/typeA.yaml
test_key: "loaded from type/typeA.yaml"

config/common.yaml
test_key: "loaded from common.yaml"
```

```ruby
config = MiniHiera.new('path/to/config', hierarchy: [
  'device/%{name}',
  'site/%{site}',
  'type/%{type}',
  'common'
])
```

Specific usage of this library can be found demonstrated in the `spec/usage_spec.rb`, which can be executed to ensure it's still accurate!

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/joshado/mini_hiera.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
